@@ -50,7 +50,7 @@ _MENTIONS_REGEXP = re.compile(r'<@([0-9A-Za-z]+)>')
 _CHANNEL_MENTIONS_REGEXP = re.compile(r'<#([A-Z0-9]+)\|[_\w-]+>')
 _URL_REGEXP = re.compile(r'<([a-z0-9\-\.]+)://([^\s\|]+)[\|]{0,1}([^<>]*)>')
 
-VERSION = '1.13'
+VERSION = '1.14'
 
 
 _SLACK_SUBSTITUTIONS = [
@@ -590,6 +590,8 @@ class Client:
         while url := _URL_REGEXP.search(i):
             schema, path, label = url.groups()
             if label and (label != f"{schema}://{path}"):
+                if '://' in label:
+                    label = 'LINK'
                 ref = str(refn).translate(refs)
                 refn += 1
                 i = (
