@@ -1,5 +1,5 @@
 # localslackirc
-# Copyright (C) 2020 Salvo "LtWorf" Tomaselli
+# Copyright (C) 2020-2021 Salvo "LtWorf" Tomaselli
 #
 # localslackirc is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,8 +18,9 @@
 
 import asyncio
 import unittest
+from pathlib import Path
 
-from irc import _MENTIONS_REGEXP, _CHANNEL_MENTIONS_REGEXP, _URL_REGEXP, Client, Provider
+from irc import _MENTIONS_REGEXP, _CHANNEL_MENTIONS_REGEXP, _URL_REGEXP, Client, Provider, ClientSettings
 from slack import Channel, User
 
 
@@ -73,7 +74,15 @@ class TestMagic(unittest.TestCase):
                 return User('0', 'LtWorf', None)
 
         self.mock_client = MockClient()
-        self.client = Client(None, self.mock_client, False, True, Provider.SLACK, set())
+        settings = ClientSettings(
+            False,
+            True,
+            Provider.SLACK,
+            set(),
+            set(),
+            Path('/tmp'),
+        )
+        self.client = Client(None, self.mock_client, settings)
 
     def test_no_replace(self):
         '''
